import { SkyComponentHarness } from '@skyux/core/testing';
import { SkyHelpInlineHarness } from '@skyux/help-inline/testing';

/**
 * Harness for interacting with a progress indicator item component in tests.
 */
class SkyProgressIndicatorItemHarness extends SkyComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-progress-indicator-item'; }
    #getHeading = this.locatorFor('.sky-progress-indicator-item-heading');
    #getIndicator = this.locatorFor('.sky-progress-indicator-status-marker');
    /**
     * Gets a `HarnessPredicate` that can be used to search for a
     * `SkyProgressIndicatorItemHarness` that meets certain criteria
     */
    static with(filters) {
        return SkyProgressIndicatorItemHarness.getDataSkyIdPredicate(filters);
    }
    /**
     * Clicks the help inline button.
     */
    async clickHelpInline() {
        await (await this.#getHelpInline()).click();
    }
    /**
     * Gets the help inline popover content.
     */
    async getHelpPopoverContent() {
        return await (await this.#getHelpInline()).getPopoverContent();
    }
    /**
     * Gets the help inline popover title.
     */
    async getHelpPopoverTitle() {
        return await (await this.#getHelpInline()).getPopoverTitle();
    }
    /**
     * Gets the progress indicator item's title text.
     */
    async getTitle() {
        const title = await (await this.#getHeading()).text();
        return title.substring(title.indexOf('-') + 1).trim();
    }
    /**
     * Whether the indicator item step is completed.
     */
    async isCompleted() {
        return await (await this.#getIndicator()).hasClass('sky-progress-indicator-status-marker-status-complete');
    }
    async #getHelpInline() {
        const harness = await this.locatorForOptional(SkyHelpInlineHarness)();
        if (harness) {
            return harness;
        }
        throw Error('No help inline found.');
    }
}

/**
 * Harness for interacting with a progress indicator component in tests.
 */
class SkyProgressIndicatorHarness extends SkyComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-progress-indicator'; }
    #getProgressIndicator = this.locatorFor('.sky-progress-indicator');
    #getResetButton = this.locatorFor('sky-progress-indicator-reset-button > .sky-btn-link');
    #getTitle = this.locatorFor('.sky-progress-indicator-title');
    /**
     * Gets a `HarnessPredicate` that can be used to search for a
     * `SkyProgressIndicatorHarness` that meets certain criteria.
     */
    static with(filters) {
        return SkyProgressIndicatorHarness.getDataSkyIdPredicate(filters);
    }
    /**
     * Clicks the reset button.
     */
    async clickResetButton() {
        try {
            await (await this.#getResetButton()).click();
        }
        catch {
            throw new Error('Unable to find reset button.');
        }
    }
    /**
     * Gets a specific progress indicator item that meets certain criteria.
     */
    async getItem(filter) {
        return await this.locatorFor(SkyProgressIndicatorItemHarness.with(filter))();
    }
    /**
     * Gets an array of all progress indicator items.
     */
    async getItems(filters) {
        const items = await this.locatorForAll(SkyProgressIndicatorItemHarness.with(filters || {}))();
        if (items.length === 0) {
            if (filters) {
                throw new Error(`Unable to find any progress indicator items with filter(s): ${JSON.stringify(filters)}`);
            }
            throw new Error('Unable to find any progress indicator items.');
        }
        return items;
    }
    /**
     * Gets the progress indicator title.
     */
    async getTitle() {
        try {
            return (await (await this.#getTitle()).text()).trim();
        }
        catch {
            throw new Error('Unable to find title.');
        }
    }
    /**
     * Whether the progress indicator is passive.
     */
    async isPassive() {
        return await (await this.#getProgressIndicator()).hasClass('sky-progress-indicator-passive');
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { SkyProgressIndicatorHarness, SkyProgressIndicatorItemHarness };
//# sourceMappingURL=skyux-progress-indicator-testing.mjs.map
